@@ -2,7 +2,7 @@ package Data::Page;
 use Carp;
 use strict;
 use vars qw($VERSION);
-$VERSION = '1.00';
+$VERSION = '1.02';
 
 =head1 NAME
 
@@ -49,8 +49,7 @@ also optionally takes the current page number (which defaults to 1).
 =cut
 
 sub new {
-  my $proto = shift;
-  my $class = ref($proto) || $proto;
+  my $class = shift;
   my $self = {};
 
   $self->{TOTAL_ENTRIES} = shift;
@@ -255,6 +254,7 @@ on the current page.
 sub splice {
   my ($self, $array) = @_;
   my $top = @$array > $self->last ? $self->last : @$array;
+  return () if $top == 0; # empty
   return @{$array}[ $self->first - 1 .. $top - 1 ];
 }
 
